@@ -214,6 +214,8 @@ public abstract class UserAbstraction extends ObjectNamingAbstraction {
     protected static final String OPT_ACCESS_MULTIPLE_MAIL_ACCOUNTS = "access-multiple-mail-accounts";
     protected static final String OPT_ACCESS_SUBSCRIPTION = "access-subscription";
     protected static final String OPT_ACCESS_PUBLICATION = "access-publication";
+    protected static final String OPT_ACCESS_ACTIVE_SYNC = "access-active-sync";
+    protected static final String OPT_ACCESS_USM = "access-usm";
     protected static final String OPT_GUI_LONG = "gui_spam_filter_capabilities_enabled";
     
     
@@ -280,6 +282,9 @@ public abstract class UserAbstraction extends ObjectNamingAbstraction {
     protected Option accessMultipleMailAccounts = null;
     protected Option accessPublication = null;
     protected Option accessSubscription = null;
+    protected Option accessActiveSync = null;
+    protected Option accessUSM = null;
+    
     
     // non-generic extended option
     protected Option addGUISettingOption = null;
@@ -580,7 +585,8 @@ public abstract class UserAbstraction extends ObjectNamingAbstraction {
         access.setMultipleMailAccounts(accessOption2BooleanCreate(parser,this.accessMultipleMailAccounts));
         access.setSubscription(accessOption2BooleanCreate(parser,this.accessSubscription));
         access.setPublication(accessOption2BooleanCreate(parser,this.accessPublication));
-        
+        access.setActiveSync(accessOption2BooleanCreate(parser,this.accessActiveSync));
+        access.setUSM(accessOption2BooleanCreate(parser, this.accessUSM));
     }
     
     protected final boolean accessOption2BooleanCreate(final AdminParser parser,final Option accessOption){
@@ -704,6 +710,14 @@ public abstract class UserAbstraction extends ObjectNamingAbstraction {
             access.setPublication(accessOption2BooleanCreate(parser, this.accessPublication));
             changed = true;
         }
+        if((String) parser.getOptionValue(this.accessActiveSync) != null) {
+        	access.setActiveSync(accessOption2BooleanCreate(parser, this.accessActiveSync));
+        	changed = true;
+        }
+        if((String) parser.getOptionValue(this.accessUSM) != null) {
+        	access.setUSM(accessOption2BooleanCreate(parser, this.accessUSM));
+        	changed = true;
+        }
         return changed;
     }
     
@@ -785,6 +799,9 @@ public abstract class UserAbstraction extends ObjectNamingAbstraction {
         this.accessMultipleMailAccounts = setLongOpt(admp, OPT_ACCESS_MULTIPLE_MAIL_ACCOUNTS,"on/off","Multiple Mail Accounts access (Default is off)", true, false,true);
         this.accessSubscription = setLongOpt(admp, OPT_ACCESS_SUBSCRIPTION,"on/off","Subscription access (Default is off)", true, false,true);
         this.accessPublication = setLongOpt(admp, OPT_ACCESS_PUBLICATION,"on/off","Publication access (Default is off)", true, false,true);
+        this.accessActiveSync = setLongOpt(admp, OPT_ACCESS_ACTIVE_SYNC, "on/off", "Exchange Active Sync access (Default is off)", true, false, true);
+        this.accessUSM = setLongOpt(admp, OPT_ACCESS_USM, "on/off", "Universal Sync access (Default is off)", true, false, true);
+        
     }
 
     protected final void setMandatoryOptions(final AdminParser parser) {
