@@ -75,6 +75,7 @@ import com.openexchange.admin.storage.interfaces.OXToolStorageInterface;
 import com.openexchange.admin.storage.interfaces.OXUserStorageInterface;
 import com.openexchange.admin.tools.AdminCache;
 import com.openexchange.admin.tools.PropertyHandler;
+import com.openexchange.database.DBPoolingException;
 import com.openexchange.groupware.update.UpdateTaskCollection;
 
 public class OXContextMySQLStorageCommon {
@@ -218,13 +219,23 @@ public class OXContextMySQLStorageCommon {
         group_stmt.close();
     }
 
-    public final void createAdminForContext(final Context ctx, final User admin_user, final Connection ox_write_con, final int internal_user_id, final int contact_id, final int uid_number, final UserModuleAccess access) throws StorageException, InvalidDataException {
-        final OXUserStorageInterface oxs = OXUserStorageInterface.getInstance();
-
-        final OXToolStorageInterface tool = OXToolStorageInterface.getInstance();
-        tool.primaryMailExists(ctx, admin_user.getPrimaryEmail());
+    /**
+     * @param ctx
+     * @param admin_user
+     * @param con writable context database connection.
+     * @param internal_user_id
+     * @param contact_id
+     * @param uid_number
+     * @param access
+     * @throws StorageException
+     * @throws InvalidDataException
+     */
+    public final void createAdminForContext(final Context ctx, final User admin_user, final Connection con, final int internal_user_id, final int contact_id, final int uid_number, final UserModuleAccess access) throws StorageException, InvalidDataException {
+        OXUserStorageInterface oxs = OXUserStorageInterface.getInstance();
+        OXToolStorageInterface tool = OXToolStorageInterface.getInstance();
+        tool.primaryMailExists(con, ctx, admin_user.getPrimaryEmail());
         admin_user.setDefaultSenderAddress(admin_user.getPrimaryEmail());
-        oxs.create(ctx, admin_user, access, ox_write_con, internal_user_id, contact_id, uid_number);
+        oxs.create(ctx, admin_user, access, con, internal_user_id, contact_id, uid_number);
     }
 
     public final void deleteContextFromConfigDB(final Connection configdb_write_con, final int context_id) throws SQLException {
@@ -260,7 +271,14 @@ public class OXContextMySQLStorageCommon {
             stmt2.executeUpdate();
             stmt2.close();
             // configdb_write_con.commit(); // temp disabled by c utmasta
-    
+
+            // tell pool, that database has been removed
+            try {
+                com.openexchange.databaseold.Database.reset(context_id);
+            } catch (DBPoolingException e) {
+                log.error(e.getMessage(), e);
+            }
+
             if (!cs2db_broken) {
                 try {
                     // check if any other context uses the same db_schema
@@ -287,8 +305,6 @@ public class OXContextMySQLStorageCommon {
                         oxutilcommon.deleteDatabase(db);
     
                         stmt3.close();
-                        // tell pool, that database has been removed
-                        com.openexchange.databaseold.Database.reset(context_id);
                     }
                     stmt2.close();
                 } catch (final Exception e) {
